==> JobOffers-0.1.3.tar.gz: JobOffers-0.1.3/job_offers/models.py <==
# -*- coding: utf-8 -*-

import functools

from django.db import models, transaction
from django.db.models import Q
from django.db.models.signals import pre_delete
from django.utils.translation import ugettext_lazy as _
from django.dispatch import receiver
from django.core.exceptions import ValidationError
from django.utils.encoding import python_2_unicode_compatible


@python_2_unicode_compatible
class Category(models.Model):
    """Model for category"""
    title = models.CharField(
        _('title'),
        max_length=500
    )

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')


@python_2_unicode_compatible
class ContractType(models.Model):
    """Model for contract_type in JobOffer"""
    title = models.CharField(
        _('title'),
        max_length=1000
    )

    def __str__(self):
        return self.title

    class Meta:
        verbose_name = _('Contract types')
        verbose_name_plural = _('Contract types')



class JobOfferQuerySet(models.QuerySet):
    def active(self):
        return self.filter(
            is_active=True
        )

    def filter_by_keywords(self, keywords):
        keyword_predicate = functools.reduce(lambda x, y: x & y, [
            Q(title__contains=word) |
            Q(job_description__contains=word) |
            Q(reference__contains=word) |
            Q(tags__contains=word) |
            Q(competences__contains=word)
            for word in keywords
        ])
        return self.filter(keyword_predicate)


@python_2_unicode_compatible
class JobOffer(models.Model):
    """Model for job offers"""
    objects = JobOfferQuerySet.as_manager()

    title = models.CharField(
        _('title'),
        max_length=500,
    )
    slug = models.SlugField(
        _('slug'),
        max_length=500,
        unique=True,
    )
    short_description = models.TextField(
        _('short description'),
        blank=True,
    )
    job_description = models.TextField(
        _('job description'),
        blank=True,
    )
    competences = models.TextField(
        _('competences'),
        blank=True,
    )
    reference = models.CharField(
        _('reference'),
        max_length=100,
        unique=True,
    )
    date = models.DateField(
        _('date'),
    )
    country = models.CharField(
        _('country'),
        max_length=50,
    )
    contract_type = models.ForeignKey(
        ContractType,
        blank=False,
        null=True,
    )
    location = models.CharField(
        _('location'),
        max_length=100,
    )
    geo_area = models.CharField(
        _('geographical area'),
        max_length=100,
        blank=True,
    )
    weight = models.IntegerField(
        _('weight'),
    )
    is_active = models.BooleanField(
        _('enabled'),
        default=True,
    )
    categories = models.ManyToManyField(
        Category,
        blank=True,
    )
    tags = models.CharField(
        _('tags'),
        max_length=100,
        blank=True,
    )

    def __str__(self):
        return self.title

    class Meta:
        ordering = ['-date']


def validate_image_max_size(fieldfile_obj):
    filesize = fieldfile_obj.file.size
    megabyte_limit = 10.0
    if filesize > megabyte_limit*1024*1024:
        raise ValidationError("Max file size is %sMB" % str(megabyte_limit))


@python_2_unicode_compatible
class Application(models.Model):
    """Model for job application"""
    job_offer = models.ForeignKey(
        JobOffer,
        verbose_name=_('job offer'),
        null=True,
    )
    last_name = models.CharField(
        _('last name'),
        max_length=50,
    )
    first_name = models.CharField(
        _('first name'),
        max_length=50,
    )
    email = models.EmailField(
        _('email'),
                              )
    phone = models.CharField(
        _('phone'),
        max_length=20,
                             )
    date = models.DateField(
        _('date'),
        blank=True,
        auto_now_add=True,
    )
    message = models.TextField(
        _('message'),
        max_length=10000,
        blank=True,
    )
    cv = models.FileField(
        _('curriculum vitae'),
        max_length=200,
        upload_to='documents/%Y/%m/%d',
        validators=[validate_image_max_size],
    )
    cover_letter = models.FileField(
        _('cover letter'),
        max_length=200,
        blank=True,
        upload_to='documents/%Y/%m/%d',
        validators=[validate_image_max_size]
    )
    other_document = models.FileField(
        _('other document'),
        max_length=200,
        blank=True,
        upload_to='documents/%Y/%m/%d',
        validators=[validate_image_max_size]
    )

    def __str__(self):
        return str(self.job_offer)


@receiver(pre_delete, sender=Application)
def after_document_delete(sender, instance, **kwargs):
    def remove_documents():
        if instance.cv:
            instance.cv.delete()
        if instance.cover_letter:
            instance.cover_letter.delete()
        if instance.other_document:
            instance.other_document.delete()

    if hasattr(transaction, 'on_commit'):
        transaction.on_commit(remove_documents)
    else:
        remove_documents()

==> JobOffers-0.3.3.dev0.tar.gz: JobOffers-0.3.3.dev0/job_offers/models.py <==
# -*- coding: utf-8 -*-

from django.db import models, transaction
from django.db.models.signals import pre_delete
from django.utils.translation import ugettext_lazy as _
from django.dispatch import receiver
from django.core.exceptions import ValidationError
from django.utils.encoding import python_2_unicode_compatible
from django.utils.functional import cached_property


def validate_image_max_size(fieldfile_obj):
    filesize = fieldfile_obj.file.size
    megabyte_limit = 10.0
    one_mega_in_bytes = 1024 * 1024
    if filesize > megabyte_limit * one_mega_in_bytes:
        raise ValidationError(u'Max file size is %sMB' % str(megabyte_limit))


@python_2_unicode_compatible
class RelatedObject(models.Model):
    name = models.CharField(
        _('name'),
        max_length=500
    )
    slug = models.CharField(
        _('slug'),
        max_length=500,
    )
    type = models.CharField(
        max_length=100,
        choices=[
            ('category', _(u'Category')),
            ('contract_type', _(u'Contract Type')),
            ('business_unit', _(u'Business Unit')),
            ('sector', _(u'Sector')),
            ('occupation', _(u'Occupation')),
            ('country', _(u'Country')),
            ('location', _(u'Location')),
            ('geo_area', _(u'Geographic area')),
            ('contact', _(u'Contact')),
        ]
    )
    image = models.ImageField(
        _('Image'),
        upload_to='related/%Y/%m/%d',
        validators=[validate_image_max_size],
        blank=True,
        null=True,
    )
    weight = models.IntegerField(
        _('weight'),
        default=0,
    )
    is_active = models.BooleanField(
        _('enabled'),
        default=True,
    )
    description = models.TextField(
        blank=True,
    )

    class Meta:
        ordering = [
            'name',
        ]
        unique_together = [
            ('slug', 'type'),
        ]

    def __str__(self):
        return self.name

    def __repr__(self):
        return '{}({})'.format(self.type, self.slug)


class JobOfferQuerySet(models.QuerySet):
    def active(self):
        return self.filter(
            is_active=True
        )


@python_2_unicode_compatible
class JobOffer(models.Model):
    """Model for job offers"""
    objects = JobOfferQuerySet.as_manager()

    title = models.CharField(
        _(u'title'),
        max_length=500,
    )
    slug = models.SlugField(
        _(u'slug'),
        max_length=500,
        unique=True,
    )
    short_description = models.TextField(
        _(u'short description'),
        blank=True,
    )
    job_description = models.TextField(
        _(u'job description'),
        blank=True,
    )
    competences = models.TextField(
        _('competences'),
        blank=True,
    )
    reference = models.CharField(
        _(u'reference'),
        max_length=100,
        unique=True,
    )
    date = models.DateField(
        _(u'date'),
    )
    weight = models.IntegerField(
        _(u'weight'),
    )
    is_active = models.BooleanField(
        _(u'enabled'),
        default=True,
    )
    tags = models.CharField(
        _(u'tags'),
        max_length=100,
        blank=True,
    )
    relations = models.ManyToManyField(
        RelatedObject,
        related_name='job_offers',
    )

    def __str__(self):
        return self.title

    class Meta:
        ordering = ['-date']

    @cached_property
    def _relations(self):
        return {r.type: r for r in self.relations.all()}

    _legal_names = {slug for slug, name in RelatedObject._meta.get_field('type').choices}

    def __getattr__(self, name):
        if name not in self._legal_names:
            try:
                return super(JobOffer, self).__getattr__(name)
            except AttributeError:
                raise AttributeError(name)
        return self._relations.get(name)

    def __setattr__(self, name, value):
        if name not in self._legal_names:
            super(JobOffer, self).__setattr__(name, value)
            return

        assert value is None or isinstance(value, RelatedObject) and value.type == name
        old = self._relations.get(name)
        if old == value:
            return

        self._relations[name] = value
        if old:
            self.relations.remove(old)
        if value:
            self.relations.add(value)


@python_2_unicode_compatible
class Application(models.Model):
    """Model for job application"""
    job_offer = models.ForeignKey(
        JobOffer,
        verbose_name=_('job offer'),
        null=True,
    )
    last_name = models.CharField(
        _('last name'),
        max_length=50,
    )
    first_name = models.CharField(
        _('first name'),
        max_length=50,
    )
    email = models.EmailField(
        _('email'),
                              )
    phone = models.CharField(
        _('phone'),
        max_length=20,
                             )
    date = models.DateField(
        _('date'),
        blank=True,
        auto_now_add=True,
    )
    message = models.TextField(
        _('message'),
        max_length=10000,
        blank=True,
    )
    cv = models.FileField(
        _('curriculum vitae'),
        max_length=200,
        upload_to='documents/%Y/%m/%d',
        validators=[validate_image_max_size],
    )
    cover_letter = models.FileField(
        _('cover letter'),
        max_length=200,
        blank=True,
        upload_to='documents/%Y/%m/%d',
        validators=[validate_image_max_size]
    )
    other_document = models.FileField(
        _('other document'),
        max_length=200,
        blank=True,
        upload_to='documents/%Y/%m/%d',
        validators=[validate_image_max_size]
    )

    def __str__(self):
        return str(self.job_offer)


@receiver(pre_delete, sender=Application)
def after_document_delete(sender, instance, **kwargs):
    def remove_documents():
        if instance.cv:
            instance.cv.delete()
        if instance.cover_letter:
            instance.cover_letter.delete()
        if instance.other_document:
            instance.other_document.delete()

    if hasattr(transaction, 'on_commit'):
        transaction.on_commit(remove_documents)
    else:
        remove_documents()
